@@ -152,7 +152,7 @@ class TestNode(unittest.TestCase):
         #path1 without getResource
         node= BIMNode(path=self.path1)
         self.assertEqual(node.name,ut.get_filename(self.path1))
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
 
         #path2 with getResource
         node= BIMNode(path=self.path2,getResource=True)        
@@ -254,15 +254,15 @@ class TestNode(unittest.TestCase):
 
         #path without getResource
         node= BIMNode(path=self.path2)
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
 
         #path with getResource
         node= BIMNode(path=self.path3,getResource=True)
-        self.assertIsNotNone(node.resource)
+        self.assertIsNotNone(node._resource)
 
         #graph with get resource
         node= BIMNode(subject=self.subject2,graph=self.bimGraph2,getResource=True)
-        self.assertIsNone(node.resource)
+        self.assertIsNone(node._resource)
         
         #graphPath with get resource
         node= BIMNode(subject=self.subject3,graphPath=self.bimGraphPath3,getResource=True)
